@@ -4,14 +4,17 @@
 
 (autoload 'custom-add-loads "cus-load")
 
-(custom-add-loads 'semantic-faces '("semantic-mode"))
+(custom-add-loads 'semantic-faces '("senator"))
 (custom-add-loads 'imenu '("semantic-imenu"))
 (custom-add-loads 'speedbar '("semantic-sb"))
 (custom-add-loads 'document '("document-vars" "document"))
-(custom-add-loads 'semantic '("document" "semantic-imenu" "semantic-mode" "semantic" "senator"))
+(custom-add-loads 'scheme '("semantic-scm"))
+(custom-add-loads 'semantic-imenu '("semantic-imenu"))
+(custom-add-loads 'semantic '("semantic-util" "semanticdb" "document" "semantic-imenu" "semantic" "senator"))
 (custom-add-loads 'working '("working"))
 (custom-add-loads 'lisp '("working"))
 (custom-add-loads 'senator '("senator"))
+(custom-add-loads 'semanticdb '("semanticdb"))
 (custom-add-loads 'isearch '("senator-isearch"))
 (custom-add-loads 'texinfo '("document"))
 (custom-add-loads 'c '("semantic-c"))
